@@ -7,6 +7,7 @@ APP = 'support'
 
 
 class FaqReadContract(Contract):
+    priority = serializers.IntegerField(min_value=0)
     title = serializers.CharField(max_length=128)
     body = serializers.CharField(max_length=2048)
 
@@ -30,8 +31,10 @@ class GlossaryID(ID):
 class FaqPoint(ListPointMixin, ContractPoint):
     _point_id = FaqID()
     _read_contract = FaqReadContract
+    _sort_by = 'priority'
 
 
 class GlossaryPoint(ListPointMixin, ContractPoint):
     _point_id = GlossaryID()
     _read_contract = GlossaryReadContract
+    _sort_by = 'priority'
